# Generated by roxygen2: do not edit by hand

S3method(print,tce_fields_tbl)
S3method(print,tce_params_tbl)
export(tce_agreements)
export(tce_benefit_types)
export(tce_bid_details)
export(tce_bid_documents)
export(tce_bid_legal_basis)
export(tce_bid_modalities)
export(tce_bid_stages)
export(tce_bid_statuses)
export(tce_bids)
export(tce_budget_statuses)
export(tce_budgeted_revenues)
export(tce_cache_clear)
export(tce_cache_info)
export(tce_catalog)
export(tce_commitment_liquidations)
export(tce_commitment_payments)
export(tce_commitment_summary)
export(tce_consideranda)
export(tce_contract_amendments)
export(tce_contract_documents)
export(tce_contract_items)
export(tce_contracts)
export(tce_creditor_types)
export(tce_debts_fines)
export(tce_determinations)
export(tce_endpoint)
export(tce_entities)
export(tce_fields)
export(tce_funding_sources)
export(tce_inactivation_reasons)
export(tce_legal_instrument_documents)
export(tce_legal_instrument_items)
export(tce_legal_instrument_participants)
export(tce_legal_instruments)
export(tce_municipal_creditor_types)
export(tce_municipal_entities)
export(tce_municipal_expenditures)
export(tce_municipal_revenues)
export(tce_municipal_transfers)
export(tce_municipalities)
export(tce_object_characteristics)
export(tce_object_classifications)
export(tce_object_nature)
export(tce_outcomes)
export(tce_params)
export(tce_payroll_types)
export(tce_person_creditor_types)
export(tce_processes)
export(tce_procurement_process_budget)
export(tce_procurement_process_documents)
export(tce_procurement_process_participants)
export(tce_procurement_processes)
export(tce_public_works)
export(tce_public_works_audits)
export(tce_public_works_contractors)
export(tce_recommendations)
export(tce_reference_codes)
export(tce_reference_dates)
export(tce_reference_sources)
export(tce_remessa_works)
export(tce_remessa_works_execution)
export(tce_remessa_works_geometry)
export(tce_request)
export(tce_retirement_outcomes)
export(tce_sanctions)
export(tce_school_transport)
export(tce_servants)
export(tce_special_accountability)
export(tce_spending_limits)
export(tce_state_commitment_items)
export(tce_state_creditor_types)
export(tce_state_entities)
export(tce_state_expenditures)
export(tce_state_price_comparison)
export(tce_state_revenues)
export(tce_sub_units)
export(tce_suppliers)
export(tce_update_indices)
importFrom(rlang,"%||%")
importFrom(rlang,.data)
importFrom(rlang,.env)
