## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  eval = FALSE,
  purl = FALSE  # The TCE-PE API is geo-restricted (Brazil-only). Skip code
                # extraction so R CMD check does not try to run it on CRAN
                # machines outside Brazil.
)

