% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/processes.R
\name{tce_debts_fines}
\alias{tce_debts_fines}
\title{Debts and fines}
\usage{
tce_debts_fines(
  ...,
  verbose = getOption("tceper.verbose", FALSE),
  cache = TRUE,
  clean_names = TRUE
)
}
\arguments{
\item{...}{Named query parameters passed directly to the API.
Common filters: \code{CodigoEfiscoUG}, \code{AnoReferencia}, \code{CodigoMunicipio}.}

\item{verbose}{If \code{TRUE}, prints the final API URL.}

\item{cache}{If \code{TRUE} (default), returns cached results when available.}

\item{clean_names}{If \code{TRUE} (default), converts column names to
\code{snake_case}.}
}
\value{
A \link[tibble:tibble-package]{tibble}.
}
\description{
Retrieve debts and fines imposed.
}
\seealso{
Other processes:
\code{\link[=tce_consideranda]{tce_consideranda()}},
\code{\link[=tce_determinations]{tce_determinations()}},
\code{\link[=tce_outcomes]{tce_outcomes()}},
\code{\link[=tce_processes]{tce_processes()}},
\code{\link[=tce_recommendations]{tce_recommendations()}},
\code{\link[=tce_retirement_outcomes]{tce_retirement_outcomes()}},
\code{\link[=tce_special_accountability]{tce_special_accountability()}},
\code{\link[=tce_spending_limits]{tce_spending_limits()}}
}
\concept{processes}
