% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reference.R
\name{tce_state_entities}
\alias{tce_state_entities}
\title{State managed entities}
\usage{
tce_state_entities(
  ...,
  verbose = getOption("tceper.verbose", FALSE),
  cache = TRUE,
  clean_names = TRUE
)
}
\arguments{
\item{...}{Named query parameters passed directly to the API.}

\item{verbose}{If \code{TRUE}, prints the final API URL.}

\item{cache}{If \code{TRUE} (default), returns cached results when available.}

\item{clean_names}{If \code{TRUE} (default), converts column names to \code{snake_case}.}
}
\value{
A \link[tibble:tibble-package]{tibble}.
}
\description{
Retrieve state-level managed entities.
}
\seealso{
Other reference:
\code{\link[=tce_creditor_types]{tce_creditor_types()}},
\code{\link[=tce_entities]{tce_entities()}},
\code{\link[=tce_funding_sources]{tce_funding_sources()}},
\code{\link[=tce_inactivation_reasons]{tce_inactivation_reasons()}},
\code{\link[=tce_municipal_entities]{tce_municipal_entities()}},
\code{\link[=tce_municipalities]{tce_municipalities()}},
\code{\link[=tce_payroll_types]{tce_payroll_types()}},
\code{\link[=tce_sub_units]{tce_sub_units()}}
}
\concept{reference}
