% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/procurement.R
\name{tce_bid_modalities}
\alias{tce_bid_modalities}
\title{Bid modalities}
\usage{
tce_bid_modalities(
  ...,
  verbose = getOption("tceper.verbose", FALSE),
  cache = TRUE,
  clean_names = TRUE
)
}
\arguments{
\item{...}{Named query parameters passed directly to the API.
Common filters: \code{CodigoEfiscoUG}, \code{AnoReferencia}, \code{CodigoMunicipio}.}

\item{verbose}{If \code{TRUE}, prints the final API URL.}

\item{cache}{If \code{TRUE} (default), returns cached results when available.}

\item{clean_names}{If \code{TRUE} (default), converts column names to
\code{snake_case}.}
}
\value{
A \link[tibble:tibble-package]{tibble}.
}
\description{
Lookup table of bid modality types.
}
\seealso{
Other procurement:
\code{\link[=tce_agreements]{tce_agreements()}},
\code{\link[=tce_bid_details]{tce_bid_details()}},
\code{\link[=tce_bid_documents]{tce_bid_documents()}},
\code{\link[=tce_bid_legal_basis]{tce_bid_legal_basis()}},
\code{\link[=tce_bid_stages]{tce_bid_stages()}},
\code{\link[=tce_bid_statuses]{tce_bid_statuses()}},
\code{\link[=tce_bids]{tce_bids()}},
\code{\link[=tce_contract_amendments]{tce_contract_amendments()}},
\code{\link[=tce_contract_documents]{tce_contract_documents()}},
\code{\link[=tce_contract_items]{tce_contract_items()}},
\code{\link[=tce_contracts]{tce_contracts()}},
\code{\link[=tce_object_characteristics]{tce_object_characteristics()}},
\code{\link[=tce_object_classifications]{tce_object_classifications()}},
\code{\link[=tce_object_nature]{tce_object_nature()}}
}
\concept{procurement}
