% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/introspection.R
\name{tce_fields}
\alias{tce_fields}
\title{List output fields for an endpoint}
\usage{
tce_fields(endpoint)
}
\arguments{
\item{endpoint}{Endpoint name (e.g., \code{"Municipios"}, \code{"Contratos"}).
Use \code{\link[=tce_catalog]{tce_catalog()}} to see all available endpoints.}
}
\value{
A tibble with columns \code{name}, \code{type}, and \code{description}. Has a
custom print method that summarises the field names at the top.
}
\description{
Returns a tibble describing the columns returned by a given endpoint.
When \code{clean_names = TRUE} (the default), column names are converted
from the API's original names to \code{snake_case}.
}
\examples{
tce_fields("Contratos")
tce_fields("Municipios")
}
\seealso{
\code{\link[=tce_params]{tce_params()}}, \code{\link[=tce_catalog]{tce_catalog()}}, \code{\link[=tce_endpoint]{tce_endpoint()}}
}
