% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/remessa.R
\name{tce_remessa_works}
\alias{tce_remessa_works}
\title{Public works details (Remessa)}
\usage{
tce_remessa_works(
  ...,
  verbose = getOption("tceper.verbose", FALSE),
  cache = TRUE,
  clean_names = TRUE
)
}
\arguments{
\item{...}{Named query parameters. Common: \code{CodigoEfiscoUG}.}

\item{verbose}{If \code{TRUE}, prints the final API URL.}

\item{cache}{If \code{TRUE} (default), returns cached results when available.}

\item{clean_names}{If \code{TRUE} (default), converts column names to \code{snake_case}.}
}
\value{
A \link[tibble:tibble-package]{tibble}.
}
\description{
Public works details (Remessa)
}
\seealso{
Other remessa:
\code{\link[=tce_benefit_types]{tce_benefit_types()}},
\code{\link[=tce_budget_statuses]{tce_budget_statuses()}},
\code{\link[=tce_legal_instrument_documents]{tce_legal_instrument_documents()}},
\code{\link[=tce_legal_instrument_items]{tce_legal_instrument_items()}},
\code{\link[=tce_legal_instrument_participants]{tce_legal_instrument_participants()}},
\code{\link[=tce_legal_instruments]{tce_legal_instruments()}},
\code{\link[=tce_procurement_process_budget]{tce_procurement_process_budget()}},
\code{\link[=tce_procurement_process_documents]{tce_procurement_process_documents()}},
\code{\link[=tce_procurement_process_participants]{tce_procurement_process_participants()}},
\code{\link[=tce_procurement_processes]{tce_procurement_processes()}},
\code{\link[=tce_reference_codes]{tce_reference_codes()}},
\code{\link[=tce_reference_dates]{tce_reference_dates()}},
\code{\link[=tce_reference_sources]{tce_reference_sources()}},
\code{\link[=tce_remessa_works_execution]{tce_remessa_works_execution()}},
\code{\link[=tce_remessa_works_geometry]{tce_remessa_works_geometry()}},
\code{\link[=tce_update_indices]{tce_update_indices()}}
}
\concept{remessa}
